@@ -1,62 +1,170 @@
-analyse_SAR.CWOSL<- structure(function(#Analyse SAR CW-OSL measurements
-  ### The function performs a SAR CW-OSL analysis on an \code{\linkS4class{RLum.Analysis}}
-  ### object including growth curve fitting.
-
-  # ===========================================================================
-  ##author<<
-  ## Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)\cr
-
-  ##section<<
-  ## version 0.5.2
-  # ===========================================================================
-
+#' Analyse SAR CW-OSL measurements
+#'
+#' The function performs a SAR CW-OSL analysis on an
+#' \code{\linkS4class{RLum.Analysis}} object including growth curve fitting.
+#'
+#' The function performs an analysis for a standard SAR protocol measurements
+#' introduced by Murray and Wintle (2000) with CW-OSL curves. For the
+#' calculation of the Lx/Tx value the function \link{calc_OSLLxTxRatio} is
+#' used. For \bold{changing the way the Lx/Tx error is calculated} use the argument
+#' \code{background.count.distribution} and \code{sigmab}, which will be passed to the function
+#' \link{calc_OSLLxTxRatio}.\cr\cr
+#'
+#' \bold{Working with IRSL data}\cr\cr
+#'
+#' The function was originally designed to work just for 'OSL' curves,
+#' following the principles of the SAR protocol. An IRSL measurement protocol
+#' may follow this procedure, e.g., post-IR IRSL protocol (Thomsen et al.,
+#' 2008). Therefore this functions has been enhanced to work with IRSL data,
+#' however, the function is only capable of analysing curves that follow the
+#' SAR protocol structure, i.e., to analyse a post-IR IRSL protocol, curve data
+#' have to be pre-selected by the user to fit the standards of the SAR
+#' protocol, i.e., Lx,Tx,Lx,Tx and so on. \cr
+#'
+#' Example: Imagine the measurement contains pIRIR50 and pIRIR225 IRSL curves.
+#' Only one curve type can be analysed at the same time: The pIRIR50 curves or
+#' the pIRIR225 curves.\cr\cr
+#'
+#' \bold{Supported rejection criteria}\cr\cr \sQuote{recycling.ratio}:
+#' calculated for every repeated regeneration dose point.\cr
+#'
+#' \sQuote{recuperation.rate}: recuperation rate calculated by comparing the
+#' Lx/Tx values of the zero regeneration point with the Ln/Tn value (the Lx/Tx
+#' ratio of the natural signal). For methodological background see Aitken and
+#' Smith (1988).\cr
+#'
+#' \sQuote{palaeodose.error}: set the allowed error for the De value, which per
+#' default should not exceed 10\%.
+#'
+#' @param object \code{\linkS4class{RLum.Analysis}}(\bold{required}): input
+#' object containing data for analysis
+#'
+#' @param signal.integral.min \code{\link{integer}} (\bold{required}): lower
+#' bound of the signal integral
+#'
+#' @param signal.integral.max \code{\link{integer}} (\bold{required}): upper
+#' bound of the signal integral
+#'
+#' @param background.integral.min \code{\link{integer}} (\bold{required}):
+#' lower bound of the background integral
+#'
+#' @param background.integral.max \code{\link{integer}} (\bold{required}):
+#' upper bound of the background integral
+#'
+#' @param rejection.criteria \code{\link{list}} (with default): provide list
+#' and set rejection criteria in percentage for further calculation. Allowed
+#' arguments are \code{recycling.ratio}, \code{recuperation.rate},
+#' \code{palaeodose.error} and \code{exceed.max.regpoint = TRUE/FALS} e.g.
+#' \code{rejection.criteria = list(recycling.ratio = 10} Per default all values
+#' are set to 10.
+#'
+#' @param dose.points \code{\link{numeric}} (optional): a numeric vector
+#' containg the dose points values Using this argument overwrites dose point
+#' values in the signal curves.
+#'
+#' @param mtext.outer \code{\link{character}} (optional): option to provide an
+#' outer margin mtext
+#'
+#' @param plot \code{\link{logical}} (with default): enables or disables plot
+#' output.
+#'
+#' @param plot.single \code{\link{logical}} (with default) or
+#' \code{\link{numeric}} (optional): single plot output (\code{TRUE/FALSE}) to
+#' allow for plotting the results in single plot windows. If a numerice vector
+#' is provided the plots can be selected individually, i.e. \code{plot.single =
+#' c(1,2,3,4)} will plot the TL and Lx, Tx curves but not the legend (5) or the
+#' growth curve (6), (7) and (8) belong to rejection criteria plots. Requires
+#' \code{plot = TRUE}.
+#'
+#' @param \dots further arguments that will be passed to the function
+#' \code{\link{plot_GrowthCurve}} or \code{\link{calc_OSLLxTxRatio}}
+#' (supported: \code{background.count.distribution} and \code{sigmab})
+#'
+#'
+#' @return A plot (optional) and an \code{\linkS4class{RLum.Results}} object is
+#' returned containing the following elements:
+#' \item{De.values}{\link{data.frame} containing De-values, De-error and
+#' further parameters} \item{LnLxTnTx.values}{\link{data.frame} of all
+#' calculated Lx/Tx values including signal, background counts and the dose
+#' points} \item{rejection.criteria}{\link{data.frame} with values that might
+#' by used as rejection criteria. NA is produced if no R0 dose point exists.}
+#' \item{Formula}{\link{formula} formula that have been used for the growth
+#' curve fitting }\cr The output should be accessed using the function
+#' \code{\link{get_RLum.Results}}.
+#'
+#'
+#' @note This function must not be mixed up with the function
+#' \code{\link{Analyse_SAR.OSLdata}}, which works with
+#' \link{Risoe.BINfileData-class} objects.\cr
+#'
+#' \bold{The function currently does only support 'OSL' or 'IRSL' data!}
+#'
+#' @section Function version: 0.5.3
+#'
+#'
+#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
+#' (France)
+#'
+#'
+#' @seealso \code{\link{calc_OSLLxTxRatio}}, \code{\link{plot_GrowthCurve}},
+#' \code{\linkS4class{RLum.Analysis}}, \code{\linkS4class{RLum.Results}}
+#' \code{\link{get_RLum.Results}}
+#'
+#'
+#' @references Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation
+#' after bleaching. Quaternary Science Reviews 7, 387-393.
+#'
+#' Duller, G., 2003. Distinguishing quartz and feldspar in single grain
+#' luminescence measurements. Radiation Measurements, 37 (2), 161-165.
+#'
+#' Murray, A.S. and Wintle, A.G., 2000. Luminescence dating of quartz using an
+#' improved single-aliquot regenerative-dose protocol. Radiation Measurements
+#' 32, 57-73.
+#'
+#' Thomsen, K.J., Murray, A.S., Jain, M., Boetter-Jensen, L., 2008. Laboratory
+#' fading rates of various luminescence signals from feldspar-rich sediment
+#' extracts. Radiation Measurements 43, 1474-1486.
+#' doi:10.1016/j.radmeas.2008.06.002
+#' @keywords datagen plot
+#' @examples
+#'
+#' ##load data
+#' ##ExampleData.BINfileData contains two BINfileData objects
+#' ##CWOSL.SAR.Data and TL.SAR.Data
+#' data(ExampleData.BINfileData, envir = environment())
+#'
+#' ##transform the values from the first position in a RLum.Analysis object
+#' object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
+#'
+#' ##perform SAR analysis
+#' results <- analyse_SAR.CWOSL(object,
+#'                   signal.integral.min = 1,
+#'                   signal.integral.max = 2,
+#'                   background.integral.min = 900,
+#'                   background.integral.max = 1000,
+#'                   log = "x",
+#'                   fit.method = "EXP")
+#'
+#' ##show De results
+#' get_RLum.Results(results)
+#'
+#' ##show LnTnLxTx table
+#' get_RLum.Results(results, data.object = "LnLxTnTx.table")
+#'
+#'
+analyse_SAR.CWOSL<- function(
   object,
-  ### \code{\linkS4class{RLum.Analysis}}(\bold{required}):
-  ### input object containing data for analysis
-
   signal.integral.min,
-  ### \code{\link{integer}} (\bold{required}): lower bound of the signal integral
-
   signal.integral.max,
-  ### \code{\link{integer}} (\bold{required}): upper bound of the signal integral
-
   background.integral.min,
-  ### \code{\link{integer}} (\bold{required}): lower bound of the background integral
-
   background.integral.max,
-  ### \code{\link{integer}} (\bold{required}): upper bound of the background integral
-
   rejection.criteria,
-  ### \code{\link{list}} (with default): provide list and set rejection criteria in
-  ### percentage for further calculation. Allowed arguments are \code{recycling.ratio},
-  ### \code{recuperation.rate}, \code{palaeodose.error} and \code{exceed.max.regpoint = TRUE/FALS}
-  ### e.g. \code{rejection.criteria = list(recycling.ratio = 10}
-  ### Per default all values are set to 10.
-
   dose.points,
-  ### \code{\link{numeric}} (optional): a numeric vector containg the dose points values
-  ### Using this argument overwrites dose point values in the signal curves.
-
   mtext.outer,
-  ### \code{\link{character}} (optional): option to provide an outer margin mtext
-
   plot = TRUE,
-  ### \code{\link{logical}} (with default): enables or disables plot output.
-
   plot.single = FALSE,
-  ### \code{\link{logical}} (with default) or \code{\link{numeric}} (optional):
-  ### single plot output (\code{TRUE/FALSE}) to allow for plotting the results
-  ### in single plot windows. If a numerice vector is provided the plots
-  ### can be selected individually, i.e. \code{plot.single = c(1,2,3,4)}
-  ### will plot the TL and Lx, Tx curves but not the legend (5)
-  ### or the growth curve (6), (7) and (8) belong to rejection criteria plots.
-  ### Requires \code{plot = TRUE}.
-
   ...
-  ### further arguments that will be passed to the function
-  ### \code{\link{plot_GrowthCurve}}
-
-){
+) {
 
 # CONFIG  -----------------------------------------------------------------
 
@@ -159,6 +267,7 @@ object!")
 
     ##remove objects
     rm(temp.recycling.ratio,temp.recuperation.rate, temp.palaeodose.error )
+
   }
 
 # Deal with extra arguments ----------------------------------------------------
@@ -175,6 +284,17 @@ object!")
   cex <- if("cex" %in% names(extraArgs)) {extraArgs$cex} else
   {1}
 
+  background.count.distribution <-
+    if ("background.count.distribution" %in% names(extraArgs)) {
+      extraArgs$background.count.distribution
+    } else
+    {
+      "non-poisson"
+    }
+
+  sigmab <- if("sigmab" %in% names(extraArgs)) {extraArgs$sigmab} else
+  {NULL}
+
 
 # Protocol Integrity Checks --------------------------------------------------
 
@@ -304,7 +424,9 @@ object!")
                  calc_OSLLxTxRatio(Lx.data=object@records[[OSL.Curves.ID[x]]]@data,
                                  Tx.data=object@records[[OSL.Curves.ID[x+1]]]@data,
                                  signal.integral,
-                                 background.integral))
+                                 background.integral,
+                                 background.count.distribution = background.count.distribution,
+                                 sigmab = sigmab))
 
                ##grep dose
                if(exists("temp.irradiation") == FALSE){
@@ -1089,112 +1211,4 @@ temp.sample <- data.frame(Dose=LnLxTnTx$Dose,
 
   return(temp.results.final)
 
-  # DOCUMENTATION - INLINEDOC LINES -----------------------------------------
-
-  ##details<<
-  ## The function performs an analysis for a standard SAR protocol measurements
-  ## introduced by Murray and Wintle (2000) with CW-OSL curves.
-  ## For the calculation of the Lx/Tx value the function \link{calc_OSLLxTxRatio}
-  ## is used. \cr\cr
-  ##
-  ## \bold{Working with IRSL data}\cr\cr
-  ##
-  ## The function was originally designed to work just for 'OSL' curves,
-  ## following the principles of the SAR protocol. An IRSL measurement protocol
-  ## may follow this procedure, e.g., post-IR IRSL protocol (Thomsen et al., 2008).
-  ## Therefore this functions has been enhanced to work with IRSL data, however,
-  ## the function is only capable of analysing curves that follow the SAR protocol structure, i.e.,
-  ## to analyse a post-IR IRSL protocol, curve data have to be pre-selected by the user to
-  ## fit the standards of the SAR protocol, i.e., Lx,Tx,Lx,Tx and so on. \cr
-  ##
-  ## Example: Imagine the measurement contains pIRIR50 and pIRIR225 IRSL curves. Only
-  ## one curve type can be analysed at the same time:
-  ## The pIRIR50 curves or the pIRIR225 curves.\cr\cr
-  ##
-  ## \bold{Supported rejection criteria}\cr\cr
-  ## \sQuote{recyling.ratio}: calculated for every repeated regeneration dose point.\cr
-  ##
-  ## \sQuote{recuperation.rate}: recuperation rate calculated by comparing the
-  ## Lx/Tx values of the zero regeneration point with the Ln/Tn value
-  ## (the Lx/Tx ratio of the natural signal).
-  ## For methodological background see Aitken and Smith (1988).\cr
-  ##
-  ## \sQuote{palaeodose.error}: set the allowed error for the De value, which per
-  ## default should not exceed 10%.
-
-  ##value<<
-  ## A plot (optional) and an \code{\linkS4class{RLum.Results}} object is
-  ## returned containing the following elements:
-  ## \item{De.values}{\link{data.frame} containing De-values,
-  ## De-error and further parameters}
-  ## \item{LnLxTnTx.values}{\link{data.frame} of all calculated Lx/Tx values
-  ## including signal, background counts and the dose points}
-  ## \item{rejection.criteria}{\link{data.frame} with values that might by
-  ## used as rejection criteria. NA is produced if no R0 dose point
-  ## exists.}
-  ## \item{Formula}{\link{formula} formula that have been used for the
-  ## growth curve fitting
-  ## }\cr
-  ## The output should be accessed using the function
-  ## \code{\link{get_RLum.Results}}.
-
-  ##references<<
-  ## Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation after bleaching.
-  ## Quaternary Science Reviews 7, 387-393.
-  ##
-  ## Duller, G., 2003. Distinguishing quartz and feldspar in single grain luminescence
-  ## measurements. Radiation Measurements, 37 (2), 161-165.
-  ##
-  ## Murray, A.S. and Wintle, A.G.,  2000. Luminescence dating of quartz using an
-  ## improved single-aliquot regenerative-dose protocol. Radiation Measurements
-  ## 32, 57-73.
-  ##
-  ## Thomsen, K.J., Murray, A.S., Jain, M., Boetter-Jensen, L., 2008.
-  ## Laboratory fading rates of various luminescence signals from feldspar-rich
-  ## sediment extracts. Radiation Measurements 43, 1474-1486.
-  ## doi:10.1016/j.radmeas.2008.06.002
-
-  ##note<<
-  ## This function must not be mixed up with the function
-  ## \code{\link{Analyse_SAR.OSLdata}}, which works with \link{Risoe.BINfileData-class}
-  ## objects.\cr
-  ##
-  ## \bold{The function currently does only support 'OSL' or 'IRSL' data!}
-
-  ##seealso<<
-  ## \code{\link{calc_OSLLxTxRatio}}, \code{\link{plot_GrowthCurve}},
-  ## \code{\linkS4class{RLum.Analysis}}, \code{\linkS4class{RLum.Results}}
-  ## \code{\link{get_RLum.Results}}
-
-  ##keyword<<
-  ## datagen
-  ## plot
-
-
-}, ex=function(){
-
-  ##load data
-  ##ExampleData.BINfileData contains two BINfileData objects
-  ##CWOSL.SAR.Data and TL.SAR.Data
-  data(ExampleData.BINfileData, envir = environment())
-
-  ##transform the values from the first position in a RLum.Analysis object
-  object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
-
-  ##perform SAR analysis
-  results <- analyse_SAR.CWOSL(object,
-                    signal.integral.min = 1,
-                    signal.integral.max = 2,
-                    background.integral.min = 900,
-                    background.integral.max = 1000,
-                    log = "x",
-                    fit.method = "EXP")
-
-  ##show De results
-  get_RLum.Results(results)
-
-  ##show LnTnLxTx table
-  get_RLum.Results(results, data.object = "LnLxTnTx.table")
-
-})#END OF STRUCTURE
-
+}
