@@ -1,81 +1,104 @@
-plot_Histogram <- structure(function(# Plot a histogram with separate error plot
-  ### Function plots a predefined histogram with an accompanying error plot
-  ### as suggested by Rex Galbraith at the UK LED in Oxford 2010.
-
-  # ===========================================================================
-  ##author<<
-  ## Michael Dietze, GFZ Potsdam (Germany), \cr
-  ## Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France), \cr
-
-  ##section<<
-  ##version 0.4.4
-  # ===========================================================================
-
+#' Plot a histogram with separate error plot
+#'
+#' Function plots a predefined histogram with an accompanying error plot as
+#' suggested by Rex Galbraith at the UK LED in Oxford 2010.
+#'
+#' If the normal curve is added, the y-axis in the histogram will show the
+#' probability density.\cr\cr 
+#' A statistic summary, i.e. a collection of statistic measures of 
+#' centrality and dispersion (and further measures) can be added by specifying 
+#' one or more of the following keywords: \code{"n"} (number of samples),
+#' \code{"mean"} (mean De value), \code{"mean.weighted"} (error-weighted mean),
+#' \code{"median"} (median of the De values), \code{"sdrel"} (relative standard
+#' deviation in percent), \code{"sdrel.weighted"} (error-weighted relative 
+#' standard deviation in percent), \code{"sdabs"} (absolute standard deviation),
+#' \code{"sdabs.weighted"} (error-weighted absolute standard deviation), 
+#' \code{"serel"} (relative standard error), \code{"serel.weighted"} (
+#' error-weighted relative standard error), \code{"seabs"} (absolute standard
+#' error), \code{"seabs.weighted"} (error-weighted absolute standard error), 
+#' \code{"kurtosis"} (kurtosis) and \code{"skewness"} (skewness).
+#'
+#' @param data \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}}
+#' object (required): for \code{data.frame}: two columns: De (\code{data[,1]})
+#' and De error (\code{data[,2]}) 
+#' @param na.rm \code{\link{logical}} (with default): excludes \code{NA}
+#' values from the data set prior to any further operations.
+#' @param mtext \code{\link{character}} (optional): further sample information
+#' (\link{mtext}).
+#' @param cex.global \code{\link{numeric}} (with default): global scaling
+#' factor.
+#' @param se \code{\link{logical}} (optional): plots standard error points over
+#' the histogram, default is \code{FALSE}.
+#' @param rug \code{\link{logical}} (optional): adds rugs to the histogram,
+#' default is \code{TRUE}.
+#' @param normal_curve \code{\link{logical}} (with default): adds a normal
+#' curve to the histogram. Mean and sd are calculated from the input data. More
+#' see details section.
+#' @param summary \code{\link{character}} (optional): add statistic measures of 
+#' centrality and dispersion to the plot. Can be one or more of several 
+#' keywords. See details for available keywords.
+#' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
+#' default): optional position coordinates or keyword (e.g. \code{"topright"})
+#' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
+#' specified to place the summary below the plot header. However, this latter
+#' option in only possible if \code{mtext} is not used. In case of coordinate
+#' specification, y-coordinate refers to the right y-axis.
+#' @param colour \code{\link{numeric}} or \link{character} (with default):
+#' optional vector of length 4 which specifies the colours of the following
+#' plot items in exactly this order: histogram bars, rug lines, normal
+#' distribution curve and standard error points\cr (e.g., \code{c("grey",
+#' "black", "red", "grey")}).
+#' @param \dots further arguments and graphical parameters passed to
+#' \code{\link{plot}} or \code{\link{hist}}. If y-axis labels are provided,
+#' these must be specified as a vector of length 2 since the plot features two
+#' axes (e.g. \code{ylab = c("axis label 1", "axis label 2")}). Y-axes limits
+#' (\code{ylim}) must be provided as vector of length four, with the first two
+#' elements specifying the left axes limits and the latter two elements giving
+#' the right axis limits.
+#' @note The input data is not restricted to a special type.
+#' @section Function version: 0.4.4
+#' @author Michael Dietze, GFZ Potsdam (Germany), \cr Sebastian Kreutzer,
+#' IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @seealso \code{\link{hist}}, \code{\link{plot}}
+#' @examples
+#'
+#' ## load data
+#' data(ExampleData.DeValues, envir = environment())
+#' ExampleData.DeValues <-
+#'   Second2Gray(ExampleData.DeValues$BT998, dose.rate = c(0.0438,0.0019))
+#'
+#' ## plot histogram the easiest way
+#' plot_Histogram(ExampleData.DeValues)
+#'
+#' ## plot histogram with some more modifications
+#' plot_Histogram(ExampleData.DeValues,
+#'                rug = TRUE,
+#'                normal_curve = TRUE,
+#'                cex.global = 0.9,
+#'                pch = 2,
+#'                colour = c("grey", "black", "blue", "green"),
+#'                summary = c("n", "mean", "sdrel"),
+#'                summary.pos = "topleft",
+#'                main = "Histogram of De-values",
+#'                mtext = "Example data set",
+#'                ylab = c(expression(paste(D[e], " distribution")),
+#'                         "Standard error"),
+#'                xlim = c(100, 250),
+#'                ylim = c(0, 0.1, 5, 20))
+#'
+#'
+plot_Histogram <- function(
   data,
-  ### \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}}
-  ### object (required): for \code{data.frame}: two columns: De
-  ### (\code{data[,1]}) and De error (\code{data[,2]})
-
-  na.exclude = TRUE,
-  ### \code{\link{logical}} (with default): excludes \code{NA} values from the
-  ### data set prior to any further operations.
-
+  na.rm = TRUE,
   mtext,
-  ### \code{\link{character}} (optional): further sample information
-  ### (\link{mtext}).
-
   cex.global,
-  ### \code{\link{numeric}} (with default): global scaling factor.
-
   se,
-  ### \code{\link{logical}} (optional): plots standard error points over the
-  ### histogram, default is \code{FALSE}.
-
   rug,
-  ### \code{\link{logical}} (optional): adds rugs to the histogram, default is
-  ### \code{TRUE}.
-
   normal_curve,
-  ### \code{\link{logical}} (with default): adds a normal curve to the
-  ### histogram. Mean and sd are calculated from the input data. More see
-  ### details section.
-
   summary,
-  ### \code{\link{character}} (optional): adds numerical output to the plot.
-  ### Can be one or more out of: \code{"n"} (number of samples), \code{"mean"} (mean De
-  ### value), \code{"mean.weighted"} (error-weighted mean), \code{"median"} (median of
-  ### the De values), \code{"kdemax"} (maximum of the KDE), \code{"sdrel"} (relative standard deviation in
-  ### percent), \code{"sdabs"} (absolute standard deviation), \code{"serel"} (relative
-  ### standard error), \code{"seabs"} (absolute standard error), \code{"skewness"} (skewness)
-  ### and \code{"kurtosis"} (kurtosis).
-  ### Note: Keywords \code{"kdemax"} is implemented for
-  ### consistency reasons, however, no KDE is shown. The bandwidth is calculated according to
-  ### \code{\link{plot_KDE}}
-
   summary.pos,
-  ### \code{\link{numeric}} or \code{\link{character}} (with default): optional
-  ### position coordinates or keyword (e.g. \code{"topright"}) for the
-  ### statistical summary. Alternatively, the keyword \code{"sub"} may be
-  ### specified to place the summary below the plot header. However, this
-  ### latter option in only possible if \code{mtext} is not used. In case
-  ### of coordinate specification, y-coordinate refers to the right y-axis.
-
   colour,
-  ### \code{\link{numeric}} or \link{character} (with default): optional vector
-  ### of length 4 which specifies the colours of the following plot items in
-  ### exactly this order: histogram bars, rug lines, normal distribution curve
-  ### and standard error points\cr
-  ### (e.g., \code{c("grey", "black", "red", "grey")}).
-
   ...
-  ### further arguments and graphical parameters passed to \code{\link{plot}} or \code{\link{hist}}.
-  ### If y-axis labels are provided, these must be specified as a vector of
-  ### length 2 since the plot features two axes (e.g. \code{ylab = c("axis
-  ### label 1", "axis label 2")}). Y-axes limits (\code{ylim}) must be
-  ### provided as vector of length four, with the first two elements
-  ### specifying the left axes limits and the latter two elements giving the
-  ### right axis limits.
-
 ) {
 
   # Integrity tests ---------------------------------------------------------
@@ -143,7 +166,7 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
   }
 
   ## optionally, count and exclude NA values and print result
-  if(na.exclude == TRUE) {
+  if(na.rm == TRUE) {
     n.NA <- sum(is.na(data[,1]))
     if(n.NA == 1) {
       print("1 NA value excluded.")
@@ -162,14 +185,14 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
   if("xlab" %in% names(extraArgs)) {
     xlab.plot <- extraArgs$xlab
   } else {
-    xlab.plot <- expression(paste(D[e], " [Gy]"))
+    xlab.plot <- expression(paste(D[e], " (Gy)"))
   }
 
   if("ylab" %in% names(extraArgs)) {
     ylab.plot <- extraArgs$ylab
   } else {
     ylab.plot <- c("Frequency",
-                   "Error")
+                   "Standard error")
   }
 
   if("breaks" %in% names(extraArgs)) {
@@ -214,15 +237,15 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
 
   ## Plot histogram -----------------------------------------------------------
   HIST <- hist(data[,1],
-	  	 main = "",
-       xlab = xlab.plot,
-       ylab = ylab.plot[1],
-       xlim = xlim.plot,
-       ylim = ylim.plot[1:2],
-       breaks = breaks.plot,
-       freq = !normal_curve,
-       col = colour[1]
-       )
+               main = "",
+               xlab = xlab.plot,
+               ylab = ylab.plot[1],
+               xlim = xlim.plot,
+               ylim = ylim.plot[1:2],
+               breaks = breaks.plot,
+               freq = !normal_curve,
+               col = colour[1]
+  )
 
   ## add title
   title(line = 2,
@@ -248,7 +271,9 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
 
   ## calculate and paste statistical summary
   data.stats <- list(data = data)
-  De.stats <- matrix(nrow = length(data.stats), ncol = 14)
+
+  ## calculate and paste statistical summary
+  De.stats <- matrix(nrow = length(data), ncol = 18)
   colnames(De.stats) <- c("n",
                           "mean",
                           "mean.weighted",
@@ -262,45 +287,51 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
                           "q25",
                           "q75",
                           "skewness",
-                          "kurtosis")
-
-  for(i in 1:length(data.stats)) {
-    statistics <- calc_Statistics(data.stats[[i]])
+                          "kurtosis",
+                          "sd.abs.weighted",
+                          "sd.rel.weighted",
+                          "se.abs.weighted",
+                          "se.rel.weighted")
+  
+  for(i in 1:length(data)) {
+    statistics <- calc_Statistics(data)
     De.stats[i,1] <- statistics$weighted$n
     De.stats[i,2] <- statistics$unweighted$mean
     De.stats[i,3] <- statistics$weighted$mean
     De.stats[i,4] <- statistics$unweighted$median
-    De.stats[i,5] <- statistics$weighted$median
-    De.stats[i,7] <- statistics$weighted$sd.abs
-    De.stats[i,8] <- statistics$weighted$sd.rel
-    De.stats[i,9] <- statistics$weighted$se.abs
+    De.stats[i,5] <- statistics$unweighted$median
+    De.stats[i,7] <- statistics$unweighted$sd.abs
+    De.stats[i,8] <- statistics$unweighted$sd.rel
+    De.stats[i,9] <- statistics$unweighted$se.abs
     De.stats[i,10] <- statistics$weighted$se.rel
-    De.stats[i,11] <- quantile(data.stats[[i]][,1], 0.25)
-    De.stats[i,12] <- quantile(data.stats[[i]][,1], 0.75)
+    De.stats[i,11] <- quantile(data[,1], 0.25)
+    De.stats[i,12] <- quantile(data[,1], 0.75)
     De.stats[i,13] <- statistics$unweighted$skewness
     De.stats[i,14] <- statistics$unweighted$kurtosis
-
-
+    De.stats[i,15] <- statistics$weighted$sd.abs
+    De.stats[i,16] <- statistics$weighted$sd.rel
+    De.stats[i,17] <- statistics$weighted$se.abs
+    De.stats[i,18] <- statistics$weighted$se.rel
+    
     ##kdemax - here a little doubled as it appears below again
-    De.density <-density(x = data.stats[[i]][,1],
+    De.density <-density(x = data[,1],
                          kernel = "gaussian",
-                         bw = "nrd0")
-
+                         from = xlim.plot[1],
+                         to = xlim.plot[2])
+    
     De.stats[i,6] <- De.density$x[which.max(De.density$y)]
-
-
   }
 
   label.text = list(NA)
-
+  
   if(summary.pos[1] != "sub") {
     n.rows <- length(summary)
-
-    for(i in 1:length(data.stats)) {
+    
+    for(i in 1:length(data)) {
       stops <- paste(rep("\n", (i - 1) * n.rows), collapse = "")
-
+      
       summary.text <- character(0)
-
+      
       for(j in 1:length(summary)) {
         summary.text <- c(summary.text,
                           paste(
@@ -377,29 +408,45 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
                                          "\n",
                                          sep = ""),
                                    ""),
-                            ifelse("in.ci" %in% summary[j] == TRUE,
-                                   paste("in confidence interval = ",
-                                         round(sum(data[[i]][,7] > -2 &
-                                                     data[[i]][,7] < 2) /
-                                                 nrow(data[[i]]) * 100 , 1),
-                                         " %",
+                            ifelse("sdabs.weighted" %in% summary[j] == TRUE,
+                                   paste("abs. weighted sd = ",
+                                         round(De.stats[i,15], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("sdrel.weighted" %in% summary[j] == TRUE,
+                                   paste("rel. weighted sd = ",
+                                         round(De.stats[i,16], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("seabs.weighted" %in% summary[j] == TRUE,
+                                   paste("abs. weighted se = ",
+                                         round(De.stats[i,17], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("serel.weighted" %in% summary[j] == TRUE,
+                                   paste("rel. weighted se = ",
+                                         round(De.stats[i,18], 2),
+                                         "\n",
                                          sep = ""),
                                    ""),
                             sep = ""))
-
       }
-
+      
       summary.text <- paste(summary.text, collapse = "")
-
+      
       label.text[[length(label.text) + 1]] <- paste(stops,
                                                     summary.text,
                                                     stops,
                                                     sep = "")
     }
   } else {
-    for(i in 1:length(data.stats)) {
+    for(i in 1:length(data)) {
+      
       summary.text <- character(0)
-
+      
       for(j in 1:length(summary)) {
         summary.text <- c(summary.text,
                           ifelse("n" %in% summary[j] == TRUE,
@@ -474,18 +521,35 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
                                        " | ",
                                        sep = ""),
                                  ""),
-                          ifelse("in.ci" %in% summary[j] == TRUE,
-                                 paste("in confidence interval = ",
-                                       round(sum(data[[i]][,7] > -2 &
-                                                   data[[i]][,7] < 2) /
-                                               nrow(data[[i]]) * 100 , 1),
-                                       " %   ",
+                          ifelse("sdabs.weighted" %in% summary[j] == TRUE,
+                                 paste("abs. weighted sd = ",
+                                       round(De.stats[i,15], 2), " %",
+                                       " | ",
                                        sep = ""),
-                                 ""))
+                                 ""),
+                          ifelse("sdrel.weighted" %in% summary[j] == TRUE,
+                                 paste("rel. weighted sd = ",
+                                       round(De.stats[i,16], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 ""),
+                          ifelse("seabs.weighted" %in% summary[j] == TRUE,
+                                 paste("abs. weighted se = ",
+                                       round(De.stats[i,17], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 ""),
+                          ifelse("serel.weighted" %in% summary[j] == TRUE,
+                                 paste("rel. weighted se = ",
+                                       round(De.stats[i,18], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 "")
+        )
       }
-
+      
       summary.text <- paste(summary.text, collapse = "")
-
+      
       label.text[[length(label.text) + 1]]  <- paste(
         "  ",
         summary.text,
@@ -579,17 +643,17 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
          ylab = "",
          axes = FALSE,
          frame.plot = FALSE
-         )
+    )
     axis(side = 4,
          labels = TRUE,
          cex = cex.global
-         )
+    )
     mtext(ylab.plot[2],
           side = 4,
           line = 3,
           cex = cex.global)
 
-#    par(new = FALSE)
+    #    par(new = FALSE)
   }
 
   ## Optionally add user-defined mtext
@@ -601,48 +665,4 @@ plot_Histogram <- structure(function(# Plot a histogram with separate error plot
   ## FUN by R Luminescence Team
   if(fun==TRUE){sTeve()}
 
-  ##details<<
-  ## If the normal curve is added, the y-axis in the histogram will show
-  ## the probability density.
-
-  ##seealso<<
-  ## \code{\link{hist}}, \code{\link{plot}}
-
-  ##referencs<<
-  ## Galbraith, R., 2010. Statistics in OSL: Some Current Questions; Ask Rex.
-  ## Oral presentation during the UK TL/OSL/ESR Meeting at the School of
-  ## Geography and the Environment, University of Oxford, 8-10 September
-  ## 2010.\cr
-  ## Galbraith, R.F. & Roberts, R.G., 2012. Statistical aspects of equivalent
-  ## dose and error calculation and display in OSL dating: An overview and
-  ## some recommendations. Quaternary Geochronology, 11, 1-27.
-
-  ##note<<
-  ## The input data is not restricted to a special type.
-
-}, ex=function(){
-  ## load data
-  data(ExampleData.DeValues, envir = environment())
-  ExampleData.DeValues <-
-    Second2Gray(ExampleData.DeValues$BT998, dose.rate = c(0.0438,0.0019))
-
-  ## plot histogram the easiest way
-  plot_Histogram(ExampleData.DeValues)
-
-  ## plot histogram with some more modifications
-  plot_Histogram(ExampleData.DeValues,
-                 rug = TRUE,
-                 normal_curve = TRUE,
-                 cex.global = 0.9,
-                 pch = 2,
-                 colour = c("grey", "black", "blue", "green"),
-                 summary = c("n", "mean", "sdrel"),
-                 summary.pos = "topleft",
-                 main = "Histogram of De-values",
-                 mtext = "Example data set",
-                 ylab = c(expression(paste(D[e], " distribution")),
-                          "Error"),
-                 xlim = c(100, 250),
-                 ylim = c(0, 0.1, 5, 20))
-
-})
\ No newline at end of file
+}
