@@ -1,90 +1,168 @@
-plot_KDE <- structure(function( # Plot kernel density estimate with statistics
-  ### Plot a kernel density estimate of measurement values in combination with
-  ### the actual values and associated error bars in ascending order.
-  ### Optionally, statistical measures such as mean, median, standard
-  ### deviation, standard error and quartile range can be provided visually
-  ### and numerically.
-
-  # ===========================================================================
-  ##author<<
-  ## Michael Dietze, GFZ Potsdam (Germany),\cr
-  ## Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne, \cr
-
-  ##section<<
-  ##version 3.5
-  # ===========================================================================
-
-  ## TODOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO
-  ## - allow shading density and angle
-  ## - get colour parameters meaningful
-  ## - maybe add line option as in plot_AbanicoPlot, add keywords to line option (e.g. "mean")
-
+#' Plot kernel density estimate with statistics
+#'
+#' Plot a kernel density estimate of measurement values in combination with the
+#' actual values and associated error bars in ascending order. Optionally,
+#' statistical measures such as mean, median, standard deviation, standard
+#' error and quartile range can be provided visually and numerically.
+#'
+#' The function allow passing several plot arguments, such as \code{main},
+#' \code{xlab}, \code{cex}. However, as the figure is an overlay of two
+#' separate plots, \code{ylim} must be specified in the order: c(ymin_axis1,
+#' ymax_axis1, ymin_axis2, ymax_axis2) when using the cumulative values plot
+#' option. Similarly, if other than the default colours are desired, the
+#' argument col must be provided with colours in the following order:
+#' probability density function, De values, De error bars, sd or qr polygon.
+#' The line type (\code{lty}) for additional measures of centrality will cycle
+#' through the default values (1, 2, ...) by default, i.e. KDE line solid,
+#' further vertical lines dashed, dotted, dash-dotted and so on. To change this
+#' behaviour specify the desired order of line types (e.g. \code{lty = c(1, 3,
+#' 2, 5)}). See examples for some further explanations. For details on the
+#' calculation of the bin-width (parameter \code{bw}) see
+#' \code{\link{density}}.\cr\cr 
+#' A statistic summary, i.e. a collection of statistic measures of 
+#' centrality and dispersion (and further measures) can be added by specifying 
+#' one or more of the following keywords: \code{"n"} (number of samples),
+#' \code{"mean"} (mean De value), \code{"mean.weighted"} (error-weighted mean),
+#' \code{"median"} (median of the De values), \code{"sdrel"} (relative standard
+#' deviation in percent), \code{"sdrel.weighted"} (error-weighted relative 
+#' standard deviation in percent), \code{"sdabs"} (absolute standard deviation),
+#' \code{"sdabs.weighted"} (error-weighted absolute standard deviation), 
+#' \code{"serel"} (relative standard error), \code{"serel.weighted"} (
+#' error-weighted relative standard error), \code{"seabs"} (absolute standard
+#' error), \code{"seabs.weighted"} (error-weighted absolute standard error), 
+#' \code{"in.ci"} (percent of samples in confidence interval, e.g. 2-sigma),
+#' \code{"kurtosis"} (kurtosis) and \code{"skewness"} (skewness).
+#'
+#' @param data \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}}
+#' object (required): for \code{data.frame}: two columns: De
+#' (\code{values[,1]}) and De error (\code{values[,2]}). For plotting multiple
+#' data sets, these must be provided as \code{list} (e.g. \code{list(dataset1,
+#' dataset2)}).
+#' @param na.rm \code{\link{logical}} (with default): exclude NA values
+#' from the data set prior to any further operations.
+#' @param weights \code{\link{logical}} (with default): calculate the KDE with
+#' De-errors as weights. Attention, using errors as weights will result in a
+#' plot similar to a a probability density plot, with all ambiguities related
+#' to this plot type!
+#' @param values.cumulative \code{\link{logical}} (with default): show
+#' cumulative individual data.
+#' @param centrality \code{\link{character}}: measure(s) of centrality, used
+#' for plotting vertical lines of the respective measure. Can be one out of
+#' \code{"mean"}, \code{"median"}, \code{"mean.weighted"},
+#' \code{"median.weighted"} and \code{"kdemax"}.
+#' @param dispersion \code{\link{character}}: measure of dispersion, used for
+#' drawing the polygon that depicts the dose distribution. One out of
+#' \code{"sd"} (standard deviation),\code{"2sd"} (2 standard deviations)
+#' \code{"qr"} (quartile range).
+#' @param summary \code{\link{character}} (optional): add statistic measures of 
+#' centrality and dispersion to the plot. Can be one or more of several 
+#' keywords. See details for available keywords.
+#' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
+#' default): optional position coordinates or keyword (e.g. \code{"topright"})
+#' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
+#' specified to place the summary below the plot header. However, this latter
+#' option in only possible if \code{mtext} is not used. In case of coordinate
+#' specification, y-coordinate refers to the right y-axis.
+#' @param polygon.col \code{\link{character}} or \code{\link{numeric}} (with
+#' default): colour of the polygon showing the dose dispersion around the
+#' central value. Only relevant if \code{dispersion} is specified.
+#' @param order \code{\link{logical}}: Order data in ascending order.
+#' @param bw \code{\link{character}} (with default): bin-width, chose a numeric
+#' value for manual setting.
+#' @param output \code{\link{logical}}: Optional output of numerical plot
+#' parameters. These can be useful to reproduce similar plots. Default is
+#' \code{FALSE}.
+#' @param \dots further arguments and graphical parameters passed to
+#' \code{\link{plot}}.
+#' @note The plot output is no 'PD' plot (cf. the discussion of Berger and
+#' Galbraith in Ancient TL; see references)!
+#' @section Function version: 3.5
+#' @author Michael Dietze, GFZ Potsdam (Germany),\cr Sebastian Kreutzer,
+#' IRAMAT-CRP2A, Universite Bordeaux Montaigne
+#' @seealso \code{\link{density}}, \code{\link{plot}}
+#' @examples
+#'
+#' ## read example data set
+#' data(ExampleData.DeValues, envir = environment())
+#' ExampleData.DeValues <-
+#'   Second2Gray(ExampleData.DeValues$BT998, c(0.0438,0.0019))
+#'
+#' ## create plot straightforward
+#' plot_KDE(data = ExampleData.DeValues)
+#'
+#' ## create plot with logarithmic x-axis
+#' plot_KDE(data = ExampleData.DeValues,
+#'          log = "x")
+#'
+#' ## create plot with user-defined labels and axes limits
+#' plot_KDE(data = ExampleData.DeValues,
+#'          main = "Dose distribution",
+#'          xlab = "Dose (s)",
+#'          ylab = c("KDE estimate", "Cumulative dose value"),
+#'          xlim = c(100, 250),
+#'          ylim = c(0, 0.08, 0, 30))
+#'
+#' ## create plot with centrality lines and distribution polygons
+#' plot_KDE(data = ExampleData.DeValues,
+#'          ylim = c(0, 0.08, 0, 35),
+#'          centrality = c("median", "mean"),
+#'          dispersion = "sd",
+#'          polygon.col = "lightblue")
+#'
+#' ## create plot with statistical summary below header
+#' plot_KDE(data = ExampleData.DeValues,
+#'          summary = c("n", "median", "skewness", "qr"))
+#'
+#' ## create plot with statistical summary as legend
+#' plot_KDE(data = ExampleData.DeValues,
+#'          summary = c("n", "mean", "sdrel", "seabs"),
+#'          summary.pos = "topleft")
+#'
+#' ## split data set into sub-groups, one is manipulated, and merge again
+#' data.1 <- ExampleData.DeValues[1:15,]
+#' data.2 <- ExampleData.DeValues[16:25,] * 1.3
+#' data.3 <- list(data.1, data.2)
+#'
+#' ## create plot with two subsets straightforward
+#' plot_KDE(data = data.3)
+#'
+#' ## create plot with two subsets and summary legend at user coordinates
+#' plot_KDE(data = data.3,
+#'          summary = c("n", "median", "skewness"),
+#'          summary.pos = c(110, 0.07),
+#'          col = c("blue", "orange"))
+#'
+#' ## example of how to use the numerical output of the function
+#' ## return plot output to draw a thicker KDE line
+#' KDE <- plot_KDE(data = ExampleData.DeValues,
+#'                 output = TRUE)
+#'
+#' ## read out coordinates of KDE graph
+#' KDE.x <- KDE$De.density[[1]]$x
+#' KDE.y <- KDE$De.density[[1]]$y
+#'
+#' ## transform y-values to right y-axis dimensions
+#' KDE.y <- KDE.y / max(KDE.y) * (nrow(ExampleData.DeValues) - 1) + 1
+#'
+#' ## draw the KDE line
+#' lines(x = KDE.x,
+#'       y = KDE.y,
+#'       lwd = 3)
+#'
+plot_KDE <- function(
   data,
-  ### \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}} object
-  ### (required): for \code{data.frame}: two columns: De (\code{values[,1]})
-  ### and De error (\code{values[,2]}). For plotting multiple data sets, these
-  ### must be provided as \code{list} (e.g. \code{list(dataset1, dataset2)}).
-
-  na.exclude = TRUE,
-  ### \code{\link{logical}} (with default): exclude NA values from the data
-  ### set prior to any further operations.
-
+  na.rm = TRUE,
   weights = FALSE,
-  ### \code{\link{logical}} (with default): calculate the KDE with De-errors
-  ### as weights. Attention, using errors as weights will result in a plot
-  ### similar to a a probability density plot, with all ambiguities related
-  ### to this plot type!
-
   values.cumulative = TRUE,
-  ### \code{\link{logical}} (with default): show cumulative individual data.
-
   centrality,
-  ### \code{\link{character}}: measure(s) of centrality, used for
-  ### plotting vertical lines of the respective measure. Can be
-  ### one out of \code{"mean"}, \code{"median"}, \code{"mean.weighted"},
-  ### \code{"median.weighted"} and \code{"kdemax"}.
-
   dispersion,
-  ### \code{\link{character}}: measure of dispersion, used for
-  ### drawing the polygon that depicts the dose distribution. One out of
-  ### \code{"sd"} (standard deviation),\code{"2sd"} (2 standard deviations)
-  ### \code{"qr"} (quartile range).
-
   summary,
-  ### \code{\link{character}} (optional): adds numerical output to the plot.
-  ### Can be one or more out of: \code{"n"} (number of samples), \code{"mean"} (mean De
-  ### value), \code{"mean.weighted"} (error-weighted mean), \code{"median"} (median of
-  ### the De values), \code{"sdrel"} (relative standard deviation in
-  ### percent), \code{"sdabs"} (absolute standard deviation), \code{"serel"} (relative
-  ### standard error), \code{"seabs"} (absolute standard error), \code{"kdemax"} (maximum
-  ### of the KDE), \code{"skewness"} (skewness) and \code{"kurtosis"} (kurtosis).
-
   summary.pos,
-  ### \code{\link{numeric}} or \code{\link{character}} (with default): optional
-  ### position coordinates or keyword (e.g. \code{"topright"}) for the
-  ### statistical summary. Alternatively, the keyword \code{"sub"} may be
-  ### specified to place the summary below the plot header. However, this
-  ### latter option in only possible if \code{mtext} is not used. In case
-  ### of coordinate specification, y-coordinate refers to the right y-axis.
-
   polygon.col,
-  ### \code{\link{character}} or \code{\link{numeric}} (with default): colour
-  ### of the polygon showing the dose dispersion around the central value.
-  ### Only relevant if \code{dispersion} is specified.
-
   order = TRUE,
-  ### \code{\link{logical}}: Order data in ascending order.
-
   bw = "nrd0",
-  ### \code{\link{character}} (with default): bin-width, chose a numeric
-  ### value for manual setting.
-
   output = FALSE,
-  ### \code{\link{logical}}: Optional output of numerical plot parameters.
-  ### These can be useful to reproduce similar plots. Default is \code{FALSE}.
-
   ...
-  ### further arguments and graphical parameters passed to \code{\link{plot}}.
 ) {
 
   ## check data and parameter consistency -------------------------------------
@@ -121,7 +199,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
     summary.pos <- "sub"
   }
 
-    mtext <- ""
+  mtext <- ""
 
   if(missing(polygon.col) == TRUE) {
     polygon.col <- rep("grey80",
@@ -139,7 +217,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
   ## data preparation steps ---------------------------------------------------
 
   ## optionally, count and exclude NA values and print result
-  if(na.exclude == TRUE) {
+  if(na.rm == TRUE) {
     for(i in 1:length(data)) {
       n.NA <- sum(is.na(data[[i]][,1]))
       if(n.NA == 1) {
@@ -147,7 +225,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
       } else if(n.NA > 1) {
         print(paste(n.NA, "NA values excluded from data set", i, "."))
       }
-      data[[i]] <- data[[i]][!is.na(data[[i]][,1]),]
+      data[[i]] <- na.exclude(data[[i]])
     }
   }
 
@@ -159,7 +237,8 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
   }
 
   ## create output variables
-  De.stats <- matrix(nrow = length(data), ncol = 14)
+  ## calculate and paste statistical summary
+  De.stats <- matrix(nrow = length(data), ncol = 18)
   colnames(De.stats) <- c("n",
                           "mean",
                           "mean.weighted",
@@ -173,7 +252,11 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                           "q25",
                           "q75",
                           "skewness",
-                          "kurtosis")
+                          "kurtosis",
+                          "sd.abs.weighted",
+                          "sd.rel.weighted",
+                          "se.abs.weighted",
+                          "se.rel.weighted")
   De.density <- list(NA)
 
   ## loop through all data sets
@@ -183,15 +266,19 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
     De.stats[i,2] <- statistics$unweighted$mean
     De.stats[i,3] <- statistics$weighted$mean
     De.stats[i,4] <- statistics$unweighted$median
-    De.stats[i,5] <- statistics$weighted$median
-    De.stats[i,7] <- statistics$weighted$sd.abs
-    De.stats[i,8] <- statistics$weighted$sd.rel
-    De.stats[i,9] <- statistics$weighted$se.abs
+    De.stats[i,5] <- statistics$unweighted$median
+    De.stats[i,7] <- statistics$unweighted$sd.abs
+    De.stats[i,8] <- statistics$unweighted$sd.rel
+    De.stats[i,9] <- statistics$unweighted$se.abs
     De.stats[i,10] <- statistics$weighted$se.rel
     De.stats[i,11] <- quantile(data[[i]][,1], 0.25)
     De.stats[i,12] <- quantile(data[[i]][,1], 0.75)
     De.stats[i,13] <- statistics$unweighted$skewness
     De.stats[i,14] <- statistics$unweighted$kurtosis
+    De.stats[i,15] <- statistics$weighted$sd.abs
+    De.stats[i,16] <- statistics$weighted$sd.rel
+    De.stats[i,17] <- statistics$weighted$se.abs
+    De.stats[i,18] <- statistics$weighted$se.rel
 
     De.density[[length(De.density) + 1]] <- if(weights == TRUE) {
       density(data[[i]][,1],
@@ -280,7 +367,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                             ifelse("kdemax" %in% summary[j] == TRUE,
                                    paste("kdemax = ",
                                          round(De.stats[i,6], 2),
-                                         "\n",
+                                         " \n ",
                                          sep = ""),
                                    ""),
                             ifelse("sdabs" %in% summary[j] == TRUE,
@@ -327,8 +414,31 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                                          " %",
                                          sep = ""),
                                    ""),
+                            ifelse("sdabs.weighted" %in% summary[j] == TRUE,
+                                   paste("abs. weighted sd = ",
+                                         round(De.stats[i,15], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("sdrel.weighted" %in% summary[j] == TRUE,
+                                   paste("rel. weighted sd = ",
+                                         round(De.stats[i,16], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("seabs.weighted" %in% summary[j] == TRUE,
+                                   paste("abs. weighted se = ",
+                                         round(De.stats[i,17], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
+                            ifelse("serel.weighted" %in% summary[j] == TRUE,
+                                   paste("rel. weighted se = ",
+                                         round(De.stats[i,18], 2),
+                                         "\n",
+                                         sep = ""),
+                                   ""),
                             sep = ""))
-
       }
 
       summary.text <- paste(summary.text, collapse = "")
@@ -399,6 +509,12 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                                        " | ",
                                        sep = ""),
                                  ""),
+                          ifelse("seabs" %in% summary[j] == TRUE,
+                                 paste("abs. se = ",
+                                       round(De.stats[i,9], 2),
+                                       " | ",
+                                       sep = ""),
+                                 ""),
                           ifelse("skewness" %in% summary[j] == TRUE,
                                  paste("skewness = ",
                                        round(De.stats[i,13], 2),
@@ -411,12 +527,6 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                                        " | ",
                                        sep = ""),
                                  ""),
-                          ifelse("seabs" %in% summary[j] == TRUE,
-                                 paste("abs. se = ",
-                                       round(De.stats[i,9], 2),
-                                       " | ",
-                                       sep = ""),
-                                 ""),
                           ifelse("in.ci" %in% summary[j] == TRUE,
                                  paste("in confidence interval = ",
                                        round(sum(data[[i]][,7] > -2 &
@@ -424,7 +534,32 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                                                nrow(data[[i]]) * 100 , 1),
                                        " %   ",
                                        sep = ""),
-                                 ""))
+                                 ""),
+                          ifelse("sdabs.weighted" %in% summary[j] == TRUE,
+                                 paste("abs. weighted sd = ",
+                                       round(De.stats[i,15], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 ""),
+                          ifelse("sdrel.weighted" %in% summary[j] == TRUE,
+                                 paste("rel. weighted sd = ",
+                                       round(De.stats[i,16], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 ""),
+                          ifelse("seabs.weighted" %in% summary[j] == TRUE,
+                                 paste("abs. weighted se = ",
+                                       round(De.stats[i,17], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 ""),
+                          ifelse("serel.weighted" %in% summary[j] == TRUE,
+                                 paste("rel. weighted se = ",
+                                       round(De.stats[i,18], 2), " %",
+                                       " | ",
+                                       sep = ""),
+                                 "")
+        )
       }
 
       summary.text <- paste(summary.text, collapse = "")
@@ -456,7 +591,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
   if("xlab" %in% names(list(...))) {
     xlab <- list(...)$xlab
   } else {
-    xlab <- expression(paste(D[e], " [Gy]"))
+    xlab <- expression(paste(D[e], " (Gy)"))
   }
 
   if("ylab" %in% names(list(...))) {
@@ -469,21 +604,21 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
     xlim.plot <- list(...)$xlim
   } else {
     xlim.plot <- c(min(c(De.global - De.error.global),
-                  De.density.range[1],
-                  na.rm = TRUE),
-              max(c(De.global + De.error.global),
-                  De.density.range[2],
-                  na.rm = TRUE))
+                       De.density.range[1],
+                       na.rm = TRUE),
+                   max(c(De.global + De.error.global),
+                       De.density.range[2],
+                       na.rm = TRUE))
   }
 
   if("ylim" %in% names(list(...))) {
-      ylim.plot <- list(...)$ylim
-    } else {
-      ylim.plot <- c(De.density.range[3],
-                De.density.range[4],
-                1,
-                max(De.stats[,1]))
-    }
+    ylim.plot <- list(...)$ylim
+  } else {
+    ylim.plot <- c(De.density.range[3],
+                   De.density.range[4],
+                   1,
+                   max(De.stats[,1]))
+  }
 
   if("log" %in% names(list(...))) {
     log.option <- list(...)$log
@@ -503,7 +638,7 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
   } else {
     if("col" %in% names(list(...))) {
       colours <- matrix(c(list(...)$col),
-                 nrow = 1)
+                        nrow = 1)
     } else {
       colours <- matrix(c("#3F489D",
                           "black",
@@ -766,106 +901,4 @@ plot_KDE <- structure(function( # Plot kernel density estimate with statistics
                 De.density = De.density))
   }
 
-
-  ##details<<
-  ## The function allow passing several plot arguments, such as \code{main},
-  ## \code{xlab}, \code{cex}. However, as the figure is an overlay of two
-  ## separate plots, \code{ylim} must be specified in the order: c(ymin_axis1,
-  ## ymax_axis1, ymin_axis2, ymax_axis2) when using the cumulative values plot
-  ## option. Similarly, if other than the default
-  ## colours are desired, the argument col must be provided with colours in
-  ## the following order: probability density function, De values, De error
-  ## bars, sd or qr polygon. The line type (\code{lty}) for additional
-  ## measures of centrality will cycle through the default values (1, 2, ...)
-  ## by default, i.e. KDE line solid, further vertical lines dashed, dotted,
-  ## dash-dotted and so on. To change this behaviour specify the desired
-  ## order of line types (e.g. \code{lty = c(1, 3, 2, 5)}).
-  ## See examples for some further explanations. For
-  ## details on the calculation of the bin-width (parameter \code{bw}) see
-  ## \code{\link{density}}.
-
-  ##seealso<<
-  ## \code{\link{density}}, \code{\link{plot}}
-
-  ##referencs<<
-  ## Berger, G.W., 2010. An alternate form of probability-distribution plot
-  ## for De values. Ancient TL 28, pp. 11-21. \cr
-  ## Berger, G.W., 2011. Response to Galbraith. Ancient TL 29, pp. 48-50. \cr
-  ## Galbraith, R.F., 2011. Some comments arising from Berger (2010). Ancient
-  ## TL 29, pp. 41-47. \cr
-  ## Galbraith, R.F. & Roberts, R.G., 2012. Statistical aspects of equivalent
-  ## dose and error calculation and display in OSL dating: An overview and
-  ## some recommendations. Quaternary Geochronology, 11, pp.1-27.
-
-  ##note<<
-  ## The plot output is no 'PD' plot (cf. the discussion of Berger and
-  ## Galbraith in Ancient TL; see references)!
-
-}, ex=function(){
-  ## read example data set
-  data(ExampleData.DeValues, envir = environment())
-  ExampleData.DeValues <-
-    Second2Gray(ExampleData.DeValues$BT998, c(0.0438,0.0019))
-
-  ## create plot straightforward
-  plot_KDE(data = ExampleData.DeValues)
-
-  ## create plot with logarithmic x-axis
-  plot_KDE(data = ExampleData.DeValues,
-           log = "x")
-
-  ## create plot with user-defined labels and axes limits
-  plot_KDE(data = ExampleData.DeValues,
-           main = "Dose distribution",
-           xlab = "Dose [s]",
-           ylab = c("KDE estimate", "Cumulative dose value"),
-           xlim = c(100, 250),
-           ylim = c(0, 0.08, 0, 30))
-
-  ## create plot with centrality lines and distribution polygons
-  plot_KDE(data = ExampleData.DeValues,
-           ylim = c(0, 0.08, 0, 35),
-           centrality = c("median", "mean"),
-           dispersion = "sd",
-           polygon.col = "lightblue")
-
-  ## create plot with statistical summary below header
-  plot_KDE(data = ExampleData.DeValues,
-           summary = c("n", "median", "skewness", "qr"))
-
-  ## create plot with statistical summary as legend
-  plot_KDE(data = ExampleData.DeValues,
-           summary = c("n", "mean", "sdrel", "seabs"),
-           summary.pos = "topleft")
-
-  ## split data set into sub-groups, one is manipulated, and merge again
-  data.1 <- ExampleData.DeValues[1:15,]
-  data.2 <- ExampleData.DeValues[16:25,] * 1.3
-  data.3 <- list(data.1, data.2)
-
-  ## create plot with two subsets straightforward
-  plot_KDE(data = data.3)
-
-  ## create plot with two subsets and summary legend at user coordinates
-  plot_KDE(data = data.3,
-           summary = c("n", "median", "skewness"),
-           summary.pos = c(110, 0.07),
-           col = c("blue", "orange"))
-
-  ## example of how to use the numerical output of the function
-  ## return plot output to draw a thicker KDE line
-  KDE <- plot_KDE(data = ExampleData.DeValues,
-                  output = TRUE)
-
-  ## read out coordinates of KDE graph
-  KDE.x <- KDE$De.density[[1]]$x
-  KDE.y <- KDE$De.density[[1]]$y
-
-  ## transform y-values to right y-axis dimensions
-  KDE.y <- KDE.y / max(KDE.y) * (nrow(ExampleData.DeValues) - 1) + 1
-
-  ## draw the KDE line
-  lines(x = KDE.x,
-        y = KDE.y,
-        lwd = 3)
-})
\ No newline at end of file
+}
